@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -365,6 +365,13 @@ class RGB(Color):
         r, g, b = self.r, self.g, self.b
         return sqrt(0.299*r**2 + 0.587*g**2 + 0.114*b**2)/255
 
+    @property
+    def luminance(self) -> float:
+        """ Perceived luminance of a color in [0, 1] range. """
+        # https://en.wikipedia.org/wiki/Relative_luminance
+        r, g, b = self.r, self.g, self.b
+        return (0.2126*r**2.2 + 0.7152*g**2.2 + 0.0722*b**2.2) / 255**2.2
+
 class HSL(Color):
     ''' Represent colors by specifying their Hue, Saturation, and lightness.
 
