@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -434,7 +434,10 @@ from tornado.autoreload import watch
 from bokeh.application import Application
 from bokeh.resources import DEFAULT_SERVER_PORT
 from bokeh.server.auth_provider import AuthModule, NullAuth
-from bokeh.server.tornado import DEFAULT_SESSION_TOKEN_EXPIRATION, DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES
+from bokeh.server.tornado import (
+    DEFAULT_SESSION_TOKEN_EXPIRATION,
+    DEFAULT_WEBSOCKET_MAX_MESSAGE_SIZE_BYTES,
+)
 from bokeh.settings import settings
 from bokeh.util.logconfig import basicConfig
 from bokeh.util.strings import format_docstring, nice_join
