@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -50,7 +50,11 @@ if TYPE_CHECKING:
 else:
     from functools import lru_cache
 
+if TYPE_CHECKING:
+    from typing_extensions import Self
+
 # Bokeh imports
+from ..settings import settings
 from ..util.strings import append_docstring, nice_join
 from ..util.warnings import warn
 from .property.descriptor_factory import PropertyDescriptorFactory
@@ -409,7 +413,7 @@ class HasProps(Serializable, metaclass=MetaHasProps):
             name=self.__qualified_model__,
         )
 
-        properties = self.properties_with_values(include_defaults=False)
+        properties = self.properties_with_values(include_defaults=settings.serialize_include_defaults())
         attributes = {key: serializer.encode(val) for key, val in properties.items()}
 
         if attributes:
@@ -743,15 +747,18 @@ class HasProps(Serializable, metaclass=MetaHasProps):
         '''
         self.apply_theme(property_values={})
 
-    def clone(self) -> HasProps:
-        ''' Duplicate a HasProps object.
+    def clone(self, **overrides: Any) -> Self:
+        ''' Duplicate a ``HasProps`` object.
 
-        This creates a shallow clone of the original model, i.e. any
-        mutable containers or child models will not be duplicated.
+        This creates a shallow clone of the original model, i.e. any mutable
+        containers or child models will not be duplicated. Allows to override
+        particular properties while cloning.
 
         '''
         attrs = self.properties_with_values(include_defaults=False, include_undefined=True)
-        return self.__class__(**{key: val for key, val in attrs.items() if val is not Undefined})
+        existing = {key: val for key, val in attrs.items() if val is not Undefined}
+        properties = {**existing, **overrides}
+        return self.__class__(**properties)
 
 KindRef = Any # TODO
 
