@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -25,7 +25,11 @@ import datetime
 from typing import Any, Union
 
 # Bokeh imports
-from ...util.serialization import convert_date_to_datetime, is_datetime_type, is_timedelta_type
+from ...util.serialization import (
+    convert_date_to_datetime,
+    is_datetime_type,
+    is_timedelta_type,
+)
 from .bases import Init, Property
 from .primitive import bokeh_integer_types
 from .singletons import Undefined
