@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -36,14 +36,23 @@ from ..themes import default as default_theme
 from ..util.callback_manager import EventCallbackManager, PropertyCallbackManager
 from ..util.serialization import make_id
 from .docs import html_repr, process_example
-from .util import HasDocumentRef, collect_models, visit_value_and_its_immediate_references
+from .util import (
+    HasDocumentRef,
+    collect_models,
+    visit_value_and_its_immediate_references,
+)
 
 if TYPE_CHECKING:
+    from typing_extensions import Self
+
     from ..core.has_props import Setter
     from ..core.query import SelectorType
     from ..document import Document
     from ..document.events import DocumentPatchedEvent
-    from ..models.callbacks import Callback as JSEventCallback, CustomCode as JSChangeCallback
+    from ..models.callbacks import (
+        Callback as JSEventCallback,
+        CustomCode as JSChangeCallback,
+    )
     from ..util.callback_manager import PropertyCallback
 
 #-----------------------------------------------------------------------------
@@ -87,7 +96,7 @@ class Model(HasProps, HasDocumentRef, PropertyCallbackManager, EventCallbackMana
 
     _id: ID
 
-    def __new__(cls, *args: Any, id: ID | None = None, **kwargs: Any) -> Model:
+    def __new__(cls, *args: Any, id: ID | None = None, **kwargs: Any) -> Self:
         obj = super().__new__(cls)
 
         # Setting 'id' implies deferred initialization, which means properties
