@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -65,7 +65,11 @@ from ...core.property_mixins import (
     ScalarTextProps,
 )
 from ...core.validation import error
-from ...core.validation.errors import BAD_COLUMN_NAME, NON_MATCHING_DATA_SOURCES_ON_LEGEND_ITEM_RENDERERS
+from ...core.validation.errors import (
+    BAD_COLUMN_NAME,
+    NON_MATCHING_DATA_SOURCES_ON_LEGEND_ITEM_RENDERERS,
+    NON_MATCHING_SCALE_BAR_UNIT,
+)
 from ...model import Model
 from ..formatters import TickFormatter
 from ..labeling import LabelingPolicy, NoOverlap
@@ -522,6 +526,11 @@ class ScaleBar(Annotation):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
 
+    @error(NON_MATCHING_SCALE_BAR_UNIT)
+    def _check_non_matching_scale_bar_unit(self):
+        if not self.dimensional.is_known(self.unit):
+            return str(self)
+
     range = Either(Instance(Range), Auto, default="auto", help="""
     The range for which to display the scale.
 
@@ -582,8 +591,7 @@ class ScaleBar(Annotation):
 
     * ``@{value}`` The current value. Optionally can provide a number
       formatter with e.g. ``@{value}{%.2f}``.
-    * ``@{unit}`` The unit of measure, by default in the short form.
-      Optionally can provide a format ``@{unit}{short}`` or ``@{unit}{long}``.
+    * ``@{unit}`` The unit of measurement.
 
     """)
 
