@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -76,6 +76,7 @@ from ..util.strings import nice_join
 from ..util.warnings import warn
 from .annotations import Annotation, Legend, Title
 from .axes import Axis
+from .dom import HTML
 from .glyphs import Glyph
 from .grids import Grid
 from .layouts import GridCommon, LayoutDOM
@@ -648,7 +649,7 @@ class Plot(LayoutDOM):
     Allows to specify which frame edges to align in multiple-plot layouts.
 
     The default is to align all edges, but users can opt-out from alignment
-    of each individual edge or all edges. Note also that other proproperties
+    of each individual edge or all edges. Note also that other properties
     may disable alignment of certain edges, especially when using fixed frame
     size (``frame_width`` and ``frame_height`` properties).
     """)
@@ -822,7 +823,7 @@ class Plot(LayoutDOM):
     """)
 
     reset_policy = Enum(ResetPolicy, default="standard", help="""
-    How a plot should respond to being reset. By deafult, the standard actions
+    How a plot should respond to being reset. By default, the standard actions
     are to clear any tool state history, return plot ranges to their original
     values, undo all selections, and emit a ``Reset`` event. If customization
     is desired, this property may be set to ``"event_only"``, which will
@@ -856,6 +857,17 @@ class Plot(LayoutDOM):
     In this case we render newly appended points only after the last stream.
     """)
 
+    attribution = List(Either(Instance(HTML), String), default=[], help="""
+    Allows to acknowledge or give credit to data, tile, etc. providers.
+
+    This can be in either HTML or plain text forms. Renderers, like
+    tile renderers, can provide additional attributions which will
+    be added after attributions provided here.
+
+    .. note::
+        This feature is experimental and may change in the short term.
+    """)
+
 class GridPlot(LayoutDOM, GridCommon):
     """ Collection of plots and other layoutables on arranged on a rectangular grid.
 
@@ -879,7 +891,7 @@ class GridPlot(LayoutDOM, GridCommon):
         Tuple(Instance(LayoutDOM), Int, Int),
         Tuple(Instance(LayoutDOM), Int, Int, Int, Int)), default=[], help="""
     A list of subplots with their associated position in the grid, row and column
-    index and optional row and column spans (the defaul span is 1).
+    index and optional row and column spans (the default span is 1).
     """)
 
     @error(REPEATED_LAYOUT_CHILD)
