@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -24,7 +24,6 @@ from ..core.properties import (
     Int,
     List,
     Seq,
-    String,
     Struct,
 )
 from ..model import Model
@@ -67,7 +66,7 @@ class Selection(Model):
 
     For "multi" glyphs such as ``Patches``, ``MultiLine``, ``MultiPolygons``,
     etc, this list records the indices of which entire sub-items are selected.
-    For example, which indidual polygons of a ``MultiPolygon`` are selected.
+    For example, which individual polygons of a ``MultiPolygon`` are selected.
     """)
 
     line_indices = Seq(Int, default=[], help="""
@@ -77,11 +76,11 @@ class Selection(Model):
     were selected by a selection tool.
     """)
 
-    multiline_indices = Dict(String, Seq(Int), default={}, help="""
+    multiline_indices = Dict(Int, Seq(Int), default={}, help="""
     The detailed point indices included in a selection on a ``MultiLine``.
 
-    This value records which points, on which lines, are part of a seletion on
-    a ``MulitLine``. The keys are the top level indices (i.e., which line)
+    This value records which points, on which lines, are part of a selection
+    on a ``MultiLine``. The keys are the top level indices (i.e. which line)
     which map to lists of indices (i.e. which points on that line).
 
     If you only need to know which lines are selected, without knowing what
