@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -59,6 +59,7 @@ from ..core.enums import (
 from ..core.has_props import abstract
 from ..core.properties import (
     Alpha,
+    Any,
     AnyRef,
     Auto,
     Bool,
@@ -94,12 +95,6 @@ from ..model import Model
 from ..util.strings import nice_join
 from .annotations import BoxAnnotation, PolyAnnotation, Span
 from .callbacks import Callback
-from .coordinates import (
-    FrameBottom,
-    FrameLeft,
-    FrameRight,
-    FrameTop,
-)
 from .dom import Template
 from .glyphs import (
     HStrip,
@@ -112,6 +107,7 @@ from .glyphs import (
     VStrip,
     XYGlyph,
 )
+from .nodes import Node
 from .ranges import Range
 from .renderers import DataRenderer, GlyphRenderer
 from .ui import UIElement
@@ -196,6 +192,10 @@ class Tool(Model):
     user interface as a tooltip.
     """)
 
+    visible = Bool(default=True, help="""
+    Whether a tool button associated with this tool should appear in the toolbar.
+    """)
+
     _known_aliases: tp.ClassVar[dict[str, tp.Callable[[], Tool]]] = {}
 
     @classmethod
@@ -345,11 +345,7 @@ class InspectTool(GestureTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    toggleable = Bool(True, help="""
-    Whether an on/off toggle button should appear in the toolbar for this
-    inspection tool. If ``False``, the viewers of a plot will not be able to
-    toggle the inspector on or off using the toolbar.
-    """)
+    toggleable = DeprecatedAlias("visible", since=(3, 4, 0))
 
 class Toolbar(UIElement):
     ''' Collect tools to display for a single plot.
@@ -441,10 +437,10 @@ DEFAULT_RANGE_OVERLAY = lambda: BoxAnnotation(
     right=nan,
     top=nan,
     bottom=nan,
-    left_limit=FrameLeft(),
-    right_limit=FrameRight(),
-    top_limit=FrameTop(),
-    bottom_limit=FrameBottom(),
+    left_limit=Node.frame.left,
+    right_limit=Node.frame.right,
+    top_limit=Node.frame.top,
+    bottom_limit=Node.frame.bottom,
     fill_color="lightgrey",
     fill_alpha=0.5,
     line_color="black",
@@ -738,7 +734,7 @@ class TapTool(Tap, SelectTool):
 
     .. warning::
         Configuring modifiers is a platform dependent feature and
-        can make this tool unsable for example on mobile devices.
+        can make this tool unusable for example on mobile devices.
 
     """).accepts(Enum(KeyModifier), lambda key_mod: {key_mod: True})
 
@@ -771,6 +767,8 @@ class TapTool(Tap, SelectTool):
 
     """)
 
+    mode = Override(default="xor")
+
 class CrosshairTool(InspectTool):
     ''' *toolbar icon*: |crosshair_icon|
 
@@ -1089,7 +1087,7 @@ class PolySelectTool(Tap, RegionSelectTool):
     The polygon selection tool allows users to make selections on a
     Plot by indicating a polygonal region with mouse clicks. single
     clicks (or taps) add successive points to the definition of the
-    polygon, and a double click (or tap) indicates the selection
+    polygon, and a press click (or tap) indicates the selection
     region is ready.
 
     See :ref:`ug_styling_plots_selected_unselected_glyphs` for information
@@ -1520,12 +1518,27 @@ class EditTool(GestureTool):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+    default_overrides = Dict(String, Any, default={}, help="""
+    Padding values overriding ``ColumnarDataSource.default_values``.
+
+    Defines values to insert into non-coordinate columns when a new glyph is
+    inserted into the ``ColumnDataSource`` columns, e.g. when a circle glyph
+    defines ``"x"``, ``"y"`` and ``"color"`` columns, adding a new point will
+    add the x and y-coordinates to ``"x"`` and ``"y"`` columns and the color
+    column will be filled with the defined default value.
+    """)
+
     empty_value = Either(Bool, Int, Float, Date, Datetime, Color, String, default=0, help="""
-    Defines the value to insert on non-coordinate columns when a new
-    glyph is inserted into the ``ColumnDataSource`` columns, e.g. when a
-    circle glyph defines 'x', 'y' and 'color' columns, adding a new
-    point will add the x and y-coordinates to 'x' and 'y' columns and
-    the color column will be filled with the defined empty value.
+    The "last resort" padding value.
+
+    This is used the same as ``default_values``, when the tool was unable
+    to figure out a default value otherwise. The tool will try the following
+    alternatives in order:
+
+    1. ``EditTool.default_overrides``
+    2. ``ColumnarDataSource.default_values``
+    3. ``ColumnarDataSource``'s inferred default values
+    4. ``EditTool.empty_value``
     """)
 
     # TODO abstract renderers = List(Instance(GlyphRenderer & ...))
@@ -1559,9 +1572,8 @@ class BoxEditTool(EditTool, Drag, Tap):
 
     The supported actions include:
 
-    * Add box: Hold shift then click and drag anywhere on the plot or double
-      tap once to start drawing, move the mouse and double tap again to finish
-      drawing.
+    * Add box: Hold shift then click and drag anywhere on the plot or press
+      once to start drawing, move the mouse and press again to finish drawing.
 
     * Move box: Click and drag an existing box, the box will be dropped once
       you let go of the mouse button.
@@ -1685,8 +1697,8 @@ class PolyDrawTool(PolyTool, Drag, Tap):
 
     The supported actions include:
 
-    * Add patch or multi-line: Double tap to add the first vertex, then use tap
-      to add each subsequent vertex, to finalize the draw action double tap to
+    * Add patch or multi-line: press to add the first vertex, then use tap
+      to add each subsequent vertex, to finalize the draw action press to
       insert the final vertex or press the ESC key.
 
     * Move patch or multi-line: Tap and drag an existing patch/multi-line, the
@@ -1774,11 +1786,11 @@ class PolyEditTool(PolyTool, Drag, Tap):
 
     The supported actions include:
 
-    * Show vertices: Double tap an existing patch or multi-line
+    * Show vertices: press an existing patch or multi-line
 
-    * Add vertex: Double tap an existing vertex to select it, the tool will
+    * Add vertex: press an existing vertex to select it, the tool will
       draw the next point, to add it tap in a new location. To finish editing
-      and add a point double tap otherwise press the ESC key to cancel.
+      and add a point press otherwise press the ESC key to cancel.
 
     * Move vertex: Drag an existing vertex and let go of the mouse button to
       release it.
@@ -1815,7 +1827,7 @@ class LineEditTool(EditTool, Drag, Tap):
 
     The supported actions include:
 
-    * Show intersections: Double tap an existing line
+    * Show intersections: press an existing line
 
     * Move point: Drag an existing point and let go of the mouse button to
       release it.
