@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,10 +22,13 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 from math import inf
+from typing import Any as any
 
 # Bokeh imports
 from ...core.has_props import abstract
 from ...core.properties import (
+    Any,
+    Auto,
     Bool,
     Color,
     ColorHex,
@@ -48,6 +51,8 @@ from ...core.properties import (
     String,
     Tuple,
 )
+from ...util.deprecation import deprecated
+from ..dom import HTML
 from ..formatters import TickFormatter
 from ..ui import Tooltip
 from .widget import Widget
@@ -59,7 +64,7 @@ from .widget import Widget
 __all__ = (
     'AutocompleteInput',
     'Checkbox',
-    'ColorMap',
+    'PaletteSelect',
     'ColorPicker',
     'FileInput',
     'InputWidget',
@@ -72,6 +77,7 @@ __all__ = (
     'Switch',
     'TextAreaInput',
     'TextInput',
+    'ColorMap',
 )
 
 #-----------------------------------------------------------------------------
@@ -89,7 +95,7 @@ class InputWidget(Widget):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    title = String(default="", help="""
+    title = Either(String, Instance(HTML), default="", help="""
     Widget's label.
     """)
 
@@ -97,18 +103,6 @@ class InputWidget(Widget):
     Either a plain text or a tooltip with a rich HTML description of the function of this widget.
     """)
 
-    @classmethod
-    def coerce_value(cls, val):
-        prop_obj = cls.lookup('value')
-        if isinstance(prop_obj, Float):
-            return float(val)
-        elif isinstance(prop_obj, Int):
-            return int(val)
-        elif isinstance(prop_obj, String):
-            return str(val)
-        else:
-            return val
-
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
@@ -420,6 +414,10 @@ class AutocompleteInput(TextInput):
     match any substring of a completion string.
     """)
 
+Options = List(Either(String, Tuple(Any, String)))
+OptionsGroups = Dict(String, Options)
+
+NotSelected = "" # TODO symbol
 
 class Select(InputWidget):
     ''' Single-select widget.
@@ -430,19 +428,22 @@ class Select(InputWidget):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    options = Either(List(Either(String, Tuple(String, String))),
-        Dict(String, List(Either(String, Tuple(String, String)))), help="""
-    Available selection options. Options may be provided either as a list of
-    possible string values, or as a list of tuples, each of the form
-    ``(value, label)``. In the latter case, the visible widget text for each
-    value will be corresponding given label. Option groupings can be provided
-    by supplying a dictionary object whose values are in the aforementioned
-    list format
-    """).accepts(List(Either(Null, String)), lambda v: [ "" if item is None else item for item in v ])
+    options = Either(Options, OptionsGroups, help="""
+    Available selection options.
 
-    value = String(default="", help="""
+    Options may be provided either as a list of possible string values, which
+    also act as options' labels, or as a list of tuples, each of the form
+    ``(value, label)``, where ``value`` can be of any type, not necessarily
+    a string. In the latter case, the visible widget text for each value will
+    be corresponding given label.
+
+    Option groupings can be provided by supplying a dictionary object whose
+    values are in the aforementioned list format.
+    """).accepts(List(Either(Null, String)), lambda v: [ NotSelected if item is None else item for item in v ])
+
+    value = Any(default=NotSelected, help="""
     Initial or selected value.
-    """).accepts(Null, lambda _: "")
+    """).accepts(Null, lambda _: NotSelected)
 
 class MultiSelect(InputWidget):
     ''' Multi-select widget.
@@ -528,8 +529,8 @@ class ColorPicker(InputWidget):
     The initial color of the picked color (named or hexadecimal)
     """)
 
-class ColorMap(InputWidget):
-    ''' Color map picker widget.
+class PaletteSelect(InputWidget):
+    ''' Color palette select widget.
 
     '''
 
@@ -538,20 +539,35 @@ class ColorMap(InputWidget):
         super().__init__(*args, **kwargs)
 
     value = Required(String, help="""
+    The name of the initial or selected color palette.
     """)
 
     items = Required(Seq(Tuple(String, Seq(Color))), help="""
+    A selection of named color palettes to choose from.
     """)
 
     swatch_width = NonNegative(Int, default=100, help="""
+    The width of the UI element showing the preview of a palette, in pixels.
     """)
 
-    swatch_height = NonNegative(Int, default=20, help="""
+    swatch_height = Either(Auto, NonNegative(Int), default="auto", help="""
+    The height of the UI element showing the preview of a palette, either in
+    pixels or automatically adjusted.
     """)
 
     ncols = Positive(Int, default=1, help="""
+    The number of columns to split the display of the palettes into.
     """)
 
+def ColorMap(*args: any, **kwargs: any) -> PaletteSelect:
+    ''' Color palette select widget.
+
+    .. deprecated:: 3.4.0
+        Use ``PaletteSelect`` widget instead.
+    '''
+    deprecated((3, 4, 0), "ColorMap widget", "PaletteSelect widget")
+    return PaletteSelect(*args, **kwargs)
+
 #-----------------------------------------------------------------------------
 # Private API
 #-----------------------------------------------------------------------------
