@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -24,18 +24,17 @@ log = logging.getLogger(__name__)
 from ...core.enums import (
     AutosizeMode,
     DateFormat,
-    FontStyle,
     NumeralLanguage,
     RoundingFunction,
-    TextAlign,
 )
 from ...core.has_props import abstract
 from ...core.properties import (
     Bool,
-    Color,
+    ColorSpec,
     Either,
     Enum,
     Float,
+    FontStyleSpec,
     Instance,
     InstanceDefault,
     Int,
@@ -44,7 +43,9 @@ from ...core.properties import (
     Override,
     Required,
     String,
+    TextAlignSpec,
 )
+from ...core.property.singletons import Intrinsic
 from ...model import Model
 from ..sources import CDSView, ColumnDataSource, DataSource
 from .widget import Widget
@@ -133,18 +134,22 @@ class StringFormatter(CellFormatter):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    font_style = Enum(FontStyle, default="normal", help="""
+    font_style = FontStyleSpec(default="normal", help="""
     An optional text font style, e.g. bold, italic.
     """)
 
-    text_align = Enum(TextAlign, default="left", help="""
+    text_align = TextAlignSpec(default="left", help="""
     An optional text align, i.e. left, center or right.
     """)
 
-    text_color = Nullable(Color, help="""
+    text_color = ColorSpec(default=None, help="""
     An optional text color.
     """)
 
+    background_color = ColorSpec(default=None, help="""
+    An optional background color.
+    """)
+
     nan_format = String("-", help="""
     Formatting to apply to NaN and None values.
     """)
@@ -290,7 +295,7 @@ class DateFormatter(StringFormatter):
         super().__init__(*args, **kwargs)
 
     format = Either(Enum(DateFormat), String, default='ISO-8601', help="""
-    The date format can be any standard  `strftime`_ format string, as well
+    The date format can be any standard `strftime`_ format string, as well
     as any of the following predefined format names:
 
     ================================================ ================== ===================
@@ -334,7 +339,7 @@ class DateFormatter(StringFormatter):
         The day of the month as a decimal number (range 01 to 31).
 
     %D
-        Equivalent to %m/%d/%y.  (Americans should note that in many
+        Equivalent to %m/%d/%y. (Americans should note that in many
         other countries %d/%m/%y is rather common. This means that in
         international context this format is ambiguous and should not
         be used.)
@@ -377,11 +382,11 @@ class DateFormatter(StringFormatter):
 
     %k
         The hour (24-hour clock) as a decimal number (range 0 to 23).
-        Single digits are preceded by a blank.  (See also %H.)
+        Single digits are preceded by a blank. (See also %H.)
 
     %l
         The hour (12-hour clock) as a decimal number (range 1 to 12).
-        Single digits are preceded by a blank.  (See also %I.)  (TZ)
+        Single digits are preceded by a blank. (See also %I.) (TZ)
 
     %m
         The month as a decimal number (range 01 to 12).
@@ -402,7 +407,7 @@ class DateFormatter(StringFormatter):
 
     %p
         Either "AM" or "PM" according to the given time value, or the
-        corresponding strings for the current locale.  Noon is treated
+        corresponding strings for the current locale. Noon is treated
         as "PM" and midnight as "AM".
 
     %P
@@ -410,7 +415,7 @@ class DateFormatter(StringFormatter):
         string for the current locale.
 
     %r
-        The time in a.m. or p.m. notation.  In the POSIX locale this
+        The time in a.m. or p.m. notation. In the POSIX locale this
         is equivalent to %I:%M:%S %p.
 
     %R
@@ -422,7 +427,7 @@ class DateFormatter(StringFormatter):
         +0000 (UTC).
 
     %S
-        The second as a decimal number (range 00 to 60).  (The range
+        The second as a decimal number (range 00 to 60). (The range
         is up to 60 to allow for occasional leap seconds.)
 
     %t
@@ -439,12 +444,12 @@ class DateFormatter(StringFormatter):
     %U
         The week number of the current year as a decimal number, range
         00 to 53, starting with the first Sunday as the first day of
-        week 01.  See also %V and %W.
+        week 01. See also %V and %W.
 
     %V
         The ISO 8601 week number (see NOTES) of the current year as a
         decimal number, range 01 to 53, where week 1 is the first week
-        that has at least 4 days in the new year.  See also %U and %W.
+        that has at least 4 days in the new year. See also %U and %W.
 
     %w
         The day of the week as a decimal, range 0 to 6, Sunday being 0.
@@ -497,7 +502,7 @@ class DateFormatter(StringFormatter):
 
 class HTMLTemplateFormatter(CellFormatter):
     ''' HTML formatter using a template.
-    This uses Underscore's `template` method and syntax.  http://underscorejs.org/#template
+    This uses Underscore's `template` method and syntax. http://underscorejs.org/#template
     The formatter has access other items in the row via the `dataContext` object passed to the formatter.
     So, for example, if another column in the datasource was named `url`, the template could access it as:
 
@@ -506,7 +511,7 @@ class HTMLTemplateFormatter(CellFormatter):
         <a href="<%= url %>"><%= value %></a>
 
     To use a different set of template delimiters, pass the appropriate values for `evaluate`, `interpolate`,
-    or `escape`.  See the Underscore `template` documentation for more information.  http://underscorejs.org/#template
+    or `escape`. See the Underscore `template` documentation for more information. http://underscorejs.org/#template
 
     Example: Simple HTML template to format the column value as code.
 
@@ -779,7 +784,7 @@ class DataTable(TableWidget):
 
     Whether columns should be fit to the available width. This results in
     no horizontal scrollbar showing up, but data can get unreadable if there
-    is not enough space available. If set to ``True``, each column's width is
+    is not enough space available. If set to True, each column's width is
     understood as maximum width.
     """)
 
@@ -814,8 +819,8 @@ class DataTable(TableWidget):
 
     selectable = Either(Bool(True), Enum("checkbox"), help="""
     Whether a table's rows can be selected or not. Using ``checkbox`` is
-    equivalent  to ``True``, but makes selection visible through a checkbox
-    for each row,  instead of highlighting rows. Multiple selection is
+    equivalent to True, but makes selection visible through a checkbox
+    for each row, instead of highlighting rows. Multiple selection is
     allowed and can be achieved by either clicking multiple checkboxes (if
     enabled) or using Shift + click on rows.
     """)
@@ -827,7 +832,7 @@ class DataTable(TableWidget):
 
     To prevent the index column from being added, set to None.
 
-    If the absolute value of index_position  is larger than the length of
+    If the absolute value of index_position is larger than the length of
     the columns, then the index will appear at the beginning or end, depending
     on the sign.
     """)
@@ -858,6 +863,54 @@ class DataTable(TableWidget):
     The height of each row in pixels.
     """)
 
+    @staticmethod
+    def from_data(data, columns=None, formatters={}, **kwargs) -> DataTable:
+        """ Create a simple table from a pandas dataframe, dictionary or ColumnDataSource.
+
+        Args:
+            data (DataFrame or dict or ColumnDataSource) :
+                The data to create the table from. If the data is a dataframe
+                or dictionary, a ColumnDataSource will be created from it.
+
+            columns (list, optional) :
+                A list of column names to use from the input data.
+                If None, use all columns. (default: None)
+
+            formatters (dict, optional) :
+                A mapping of column names and corresponding Formatters to
+                apply to each column. (default: None)
+
+        Keyword arguments:
+            Any additional keyword arguments will be passed to DataTable.
+
+        Returns:
+            DataTable
+
+        Raises:
+            ValueError
+                If the provided data is not a ColumnDataSource
+                or a data source that a ColumnDataSource can be created from.
+
+        """
+
+        if isinstance(data, ColumnDataSource):
+            source = data.clone()
+        else:
+            try:
+                source = ColumnDataSource(data)
+            except ValueError as e:
+                raise ValueError("Expected a ColumnDataSource or something a ColumnDataSource can be created from like a dict or a DataFrame") from e
+
+        if columns is not None:
+            source.data = {col: source.data[col] for col in columns}
+
+        table_columns = []
+        for c in source.data.keys():
+            formatter = formatters.get(c, Intrinsic)
+            table_columns.append(TableColumn(field=c, title=c, formatter=formatter))
+
+        return DataTable(source=source, columns=table_columns, index_position=None, **kwargs)
+
 class GroupingInfo(Model):
     '''Describes how to calculate totals and sub-totals
 
