@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -22,6 +22,7 @@ from functools import wraps
 from inspect import Parameter, Signature
 
 # Bokeh imports
+from ..util.deprecation import deprecated
 from ._docstring import generate_docstring
 from ._renderer import create_renderer
 
@@ -54,6 +55,7 @@ def marker_method():
 
         @wraps(func)
         def wrapped(self, *args, **kwargs):
+            deprecated((3, 4, 0), f"{func.__name__}() method", f"scatter(marker={func.__name__!r}, ...) instead")
             if len(args) > len(glyphclass._args):
                 raise TypeError(f"{func.__name__} takes {len(glyphclass._args)} positional argument but {len(args)} were given")
             for arg, param in zip(args, sigparams[1:]):
