@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -36,8 +36,10 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import json
+import os
 import re
-from os.path import basename, join, relpath
+from os.path import relpath
+from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Callable,
@@ -57,7 +59,7 @@ from .core.types import ID, PathLike
 from .model import Model
 from .settings import LogLevel, settings
 from .util.dataclasses import dataclass, field
-from .util.paths import ROOT_DIR, bokehjsdir
+from .util.paths import ROOT_DIR
 from .util.token import generate_session_id
 from .util.version import is_full_release
 
@@ -100,49 +102,17 @@ class ComponentDefs(TypedDict):
 
 Hashes: TypeAlias = dict[str, str]
 
-_SRI_HASHES: dict[str, Hashes] | None = None
+_ALL_SRI_HASHES: dict[str, Hashes] = {}
 
-def get_all_sri_hashes() -> dict[str, Hashes]:
-    """ Report SRI script hashes for all versions of BokehJS.
-
-    Bokeh provides `Subresource Integrity`_ hashes for all JavaScript files that
-    are published to CDN for full releases. This function returns a dictionary
-    that maps version strings to sub-dictionaries that JavaScipt filenames to
-    their hashes.
+def get_all_sri_versions() -> tuple[str, ...]:
+    """ Report all versions that have SRI hashes.
 
     Returns:
-        dict
-
-    Example:
-
-        The returned dict will map version strings to sub-dictionaries for each
-        version:
-
-        .. code-block:: python
-
-            {
-                '1.4.0': {
-                    'bokeh-1.4.0.js': 'vn/jmieHiN+ST+GOXzRU9AFfxsBp8gaJ/wvrzTQGpIKMsdIcyn6U1TYtvzjYztkN',
-                    'bokeh-1.4.0.min.js': 'mdMpUZqu5U0cV1pLU9Ap/3jthtPth7yWSJTu1ayRgk95qqjLewIkjntQDQDQA5cZ',
-                    ...
-                }
-                '1.3.4': {
-                    ...
-                }
-                ...
-            }
-
-    .. _Subresource Integrity: https://developer.mozilla.org/en-US/docs/Web/Security/Subresource_Integrity
+        tuple
 
     """
-    global _SRI_HASHES
-
-    if not _SRI_HASHES:
-        with open(join(ROOT_DIR, "_sri.json"), "rb") as f:
-            _SRI_HASHES = json.load(f)
-
-    assert _SRI_HASHES is not None
-    return dict(_SRI_HASHES)
+    files = (ROOT_DIR / "_sri").glob("*.json")
+    return set(file.stem for file in files)
 
 
 def get_sri_hashes_for_version(version: str) -> Hashes:
@@ -163,7 +133,7 @@ def get_sri_hashes_for_version(version: str) -> Hashes:
         dict
 
     Raises:
-        KeyError: if the specified version does not exist
+        ValueError: if the specified version does not exist
 
     Example:
 
@@ -186,8 +156,13 @@ def get_sri_hashes_for_version(version: str) -> Hashes:
     .. _Subresource Integrity: https://developer.mozilla.org/en-US/docs/Web/Security/Subresource_Integrity
 
     """
-    hashes = get_all_sri_hashes()
-    return hashes[version]
+    if version not in _ALL_SRI_HASHES:
+        try:
+            with open(ROOT_DIR / "_sri" / f"{version}.json") as f:
+                _ALL_SRI_HASHES[version] = json.load(f)
+        except Exception as e:
+            raise ValueError(f"Missing SRI hash for version {version}") from e
+    return _ALL_SRI_HASHES[version]
 
 
 def verify_sri_hashes() -> None:
@@ -213,9 +188,7 @@ def verify_sri_hashes() -> None:
     if not is_full_release():
         raise ValueError("verify_sri_hashes() can only be used with full releases")
 
-    from glob import glob
-    paths = glob(join(bokehjsdir(), "js/bokeh*.js"))
-
+    paths = list((settings.bokehjs_path() / "js").glob("bokeh*.js"))
     hashes = get_sri_hashes_for_version(__version__)
 
     if len(hashes) < len(paths):
@@ -224,9 +197,9 @@ def verify_sri_hashes() -> None:
     if len(hashes) > len(paths):
         raise RuntimeError("There are 'bokeh*.js' files missing in the package")
 
-    bad: list[str] = []
+    bad: list[Path] = []
     for path in paths:
-        name, suffix = basename(path).split(".", 1)
+        name, suffix = str(path.name).split(".", 1)
         filename = f"{name}-{__version__}.{suffix}"
         sri_hash = _compute_single_hash(path)
         if hashes[filename] != sri_hash:
@@ -310,7 +283,7 @@ class Resources:
 
     """
 
-    _default_root_dir = "."
+    _default_root_dir = Path(os.curdir)
     _default_root_url = DEFAULT_SERVER_HTTP_URL
 
     mode: BaseMode
@@ -339,7 +312,7 @@ class Resources:
         root_url: str | None = None,
         path_versioner: PathVersioner | None = None,
         components: list[Component] | None = None,
-        base_dir: str | None = None, # TODO: PathLike
+        base_dir: PathLike | None = None,
     ):
         self.components = components if components is not None else list(self._default_components)
         mode = settings.resources(mode)
@@ -367,7 +340,7 @@ class Resources:
         del root_dir
         self.version = settings.cdn_version(version)
         del version
-        self.minified = settings.minified(minified)
+        self.minified = settings.minified(minified if minified is not None else not self.dev)
         del minified
         self.log_level = settings.log_level(log_level)
         del log_level
@@ -388,7 +361,7 @@ class Resources:
             server = self._server_urls()
             self.messages.extend(server.messages)
 
-        self.base_dir = base_dir if base_dir is not None else bokehjsdir(self.dev)
+        self.base_dir = Path(base_dir) if base_dir is not None else settings.bokehjs_path()
 
     def clone(self, *, components: list[Component] | None = None) -> Resources:
         """ Make a clone of a resources instance allowing to override its components. """
@@ -447,11 +420,11 @@ class Resources:
     def components_for(self, kind: Kind) -> list[Component]:
         return [comp for comp in self.components if comp in self._component_defs[kind]]
 
-    def _file_paths(self, kind: Kind) -> list[str]:
-        minified = ".min" if not self.dev and self.minified else ""
+    def _file_paths(self, kind: Kind) -> list[Path]:
+        minified = ".min" if self.minified else ""
 
         files = [f"{component}{minified}.{kind}" for component in self.components_for(kind)]
-        paths = [join(self.base_dir, kind, file) for file in files]
+        paths = [self.base_dir / kind / file for file in files]
         return paths
 
     def _collect_external_resources(self, resource_attr: ResourceAttr) -> list[str]:
@@ -475,7 +448,7 @@ class Resources:
         return _get_cdn_urls(self.version, self.minified)
 
     def _server_urls(self) -> Urls:
-        return _get_server_urls(self.root_url, False if self.dev else self.minified, self.path_versioner)
+        return _get_server_urls(self.root_url, self.minified, self.path_versioner)
 
     def _resolve(self, kind: Kind) -> tuple[list[str], list[str], Hashes]:
         paths = self._file_paths(kind)
@@ -486,9 +459,9 @@ class Resources:
             raw = [self._inline(path) for path in paths]
         elif self.mode == "relative":
             root_dir = self.root_dir or self._default_root_dir
-            files = [relpath(path, root_dir) for path in paths]
+            files = [str(relpath(path, root_dir)) for path in paths]
         elif self.mode == "absolute":
-            files = list(paths)
+            files = list(map(str, paths))
         elif self.mode == "cdn":
             cdn = self._cdn_urls()
             files = list(cdn.urls(self.components_for(kind), kind))
@@ -501,8 +474,8 @@ class Resources:
         return (files, raw, hashes)
 
     @staticmethod
-    def _inline(path: str) -> str:
-        filename = basename(path)
+    def _inline(path: Path) -> str:
+        filename = path.name
         begin = f"/* BEGIN {filename} */"
         with open(path, "rb") as f:
             middle = f.read().decode("utf-8")
@@ -663,8 +636,8 @@ def _get_server_urls(
     return Urls(urls=lambda components, kind: [mk_url(component, kind) for component in components])
 
 
-def _compute_single_hash(path: str) -> str:
-    assert path.endswith(".js")
+def _compute_single_hash(path: Path) -> str:
+    assert path.suffix == ".js"
 
     from subprocess import PIPE, Popen
 
@@ -691,7 +664,7 @@ __all__ = (
     "CDN",
     "INLINE",
     "Resources",
-    "get_all_sri_hashes",
+    "get_all_sri_versions",
     "get_sri_hashes_for_version",
     "verify_sri_hashes",
 )
