@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -118,7 +118,8 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 import os
-from os.path import abspath, expanduser, join
+from os.path import join
+from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -135,7 +136,8 @@ from typing import (
 import yaml
 
 # Bokeh imports
-from .util.paths import bokehjsdir, serverdir
+from .util.deprecation import deprecated
+from .util.paths import bokehjs_path, server_path
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
@@ -317,11 +319,11 @@ def convert_ico_path(value: str) -> str:
         return "none"
 
     if lowered == "default":
-        return join(serverdir(), "views", "bokeh.ico")
+        return str(server_path() / "views" / "bokeh.ico")
 
     # undocumented
     if lowered == "default-dev":
-        return join(serverdir(), "views", "bokeh-dev.ico")
+        return str(server_path() / "views" / "bokeh-dev.ico")
 
     if not value.endswith(".ico"):
         raise ValueError(f"Cannot convert {value!r} to valid .ico path")
@@ -509,8 +511,8 @@ class PrioritizedSetting(Generic[T]):
             return "Ico Path"
         raise RuntimeError("unreachable")
 
-_config_user_locations: Sequence[str] = (
-    join(expanduser("~"), ".bokeh", "bokeh.yaml"),
+_config_user_locations: Sequence[Path] = (
+    Path.home() / ".bokeh" / "bokeh.yaml",
 )
 
 class Settings:
@@ -689,7 +691,7 @@ class Settings:
 
     """)
 
-    resources: PrioritizedSetting[ResourcesMode] = PrioritizedSetting("resources", "BOKEH_RESOURCES", default="cdn", dev_default="absolute-dev", help="""
+    resources: PrioritizedSetting[ResourcesMode] = PrioritizedSetting("resources", "BOKEH_RESOURCES", default="cdn", dev_default="server", help="""
     What kind of BokehJS resources to configure, e.g ``inline`` or ``cdn``
 
     See the :class:`~bokeh.resources.Resources` class reference for full details.
@@ -713,8 +715,15 @@ class Settings:
     A long, cryptographically-random secret unique to a Bokeh deployment.
     """)
 
+    serialize_include_defaults: PrioritizedSetting[bool] = \
+        PrioritizedSetting("serialize_include_defaults", "BOKEH_SERIALIZE_INCLUDE_DEFAULTS", default=False, help="""
+    Wether to include default values when serializing ``HasProps`` instances.
+
+    This is primarily useful for testing, debugging serialization/protocol and other internal purpose.
+    """)
+
     sign_sessions: PrioritizedSetting[bool] = PrioritizedSetting("sign_sessions", "BOKEH_SIGN_SESSIONS", default=False, help="""
-    Whether the Boeh server should only allow sessions signed with a secret key.
+    Whether the Bokeh server should only allow sessions signed with a secret key.
 
     If True, ``BOKEH_SECRET_KEY`` must also be set.
     """)
@@ -763,18 +772,27 @@ class Settings:
 
     # Non-settings methods
 
-    def bokehjsdir(self) -> str:
+    def bokehjs_path(self) -> Path:
         ''' The location of the BokehJS source tree.
 
         '''
-        return bokehjsdir(self.dev)
+        return bokehjs_path(self.dev)
+
+    def bokehjsdir(self) -> str:
+        ''' The location of the BokehJS source tree.
+
+        .. deprecated:: 3.4.0
+            Use ``bokehjs_path()`` method instead.
+        '''
+        deprecated((3, 4, 0), "bokehjsdir()", "bokehjs_path() method")
+        return str(self.bokehjs_path())
 
     def css_files(self) -> list[str]:
         ''' The CSS files in the BokehJS directory.
 
         '''
         css_files: list[str] = []
-        for root, _, files in os.walk(self.bokehjsdir()):
+        for root, _, files in os.walk(self.bokehjs_path()):
             for fname in files:
                 if fname.endswith(".css"):
                     css_files.append(join(root, fname))
@@ -785,20 +803,21 @@ class Settings:
 
         '''
         js_files: list[str] = []
-        for root, _, files in os.walk(self.bokehjsdir()):
+        for root, _, files in os.walk(self.bokehjs_path()):
             for fname in files:
                 if fname.endswith(".js"):
                     js_files.append(join(root, fname))
         return js_files
 
-    def load_config(self, location: str) -> None:
+    def load_config(self, location: PathLike) -> None:
         ''' Load a user-specified override config file.
 
         The file should be a YAML format with ``key: value`` lines.
 
         '''
         try:
-            self._config_override = yaml.load(open(abspath(location)), Loader=yaml.SafeLoader)
+            with Path(location).absolute().open() as f:
+                self._config_override = yaml.load(f, Loader=yaml.SafeLoader)
         except Exception:
             raise RuntimeError(f"Could not load Bokeh config file: {location}")
 
@@ -814,10 +833,11 @@ class Settings:
                 self._secret_key_bytes = key.encode("utf-8")
         return self._secret_key_bytes
 
-    def _try_load_config(self, locations: Sequence[str]) -> dict[str, Any]:
+    def _try_load_config(self, locations: Sequence[Path]) -> dict[str, Any]:
         for location in locations:
             try:
-                return yaml.load(open(location), Loader=yaml.SafeLoader)
+                with location.open() as f:
+                    return yaml.load(f, Loader=yaml.SafeLoader)
             except Exception:
                 pass
         return {}
